# TrueMatch - Record Linkage Toolkit

TrueMatch is a record linkage python package currently work in progress. 

The program is part of my PhD thesis. Since the thesis is not published yet, I am not allowed to share the code. The planned release is end of year 2026. Until then, I try to reserve the name to avoid last-minute surprises.
